Class: Freeclimb::CallResult

Inherits:
Object
  • Object
show all
Defined in:
lib/freeclimb/models/call_result.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CallResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/freeclimb/models/call_result.rb', line 230

def initialize(attributes = {})
  if !attributes.is_a?(Hash)
    fail ArgumentError, "The input argument (attributes) must be a hash in `Freeclimb::CallResult` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if !self.class.attribute_map.key?(k.to_sym)
      fail ArgumentError, "`#{k}` is not a valid attribute in `Freeclimb::CallResult`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:uri)
    self.uri = attributes[:uri]
  end

  if attributes.key?(:date_created)
    self.date_created = attributes[:date_created]
  end

  if attributes.key?(:date_updated)
    self.date_updated = attributes[:date_updated]
  end

  if attributes.key?(:revision)
    self.revision = attributes[:revision]
  end

  if attributes.key?(:date_created_iso)
    self.date_created_iso = attributes[:date_created_iso]
  end

  if attributes.key?(:date_updated_iso)
    self.date_updated_iso = attributes[:date_updated_iso]
  end

  if attributes.key?(:call_id)
    self.call_id = attributes[:call_id]
  end

  if attributes.key?(:parent_call_id)
    self.parent_call_id = attributes[:parent_call_id]
  end

  if attributes.key?(:account_id)
    self. = attributes[:account_id]
  end

  if attributes.key?(:from)
    self.from = attributes[:from]
  end

  if attributes.key?(:to)
    self.to = attributes[:to]
  end

  if attributes.key?(:phone_number_id)
    self.phone_number_id = attributes[:phone_number_id]
  end

  if attributes.key?(:status)
    self.status = attributes[:status]
  end

  if attributes.key?(:start_time)
    self.start_time = attributes[:start_time]
  end

  if attributes.key?(:start_time_iso)
    self.start_time_iso = attributes[:start_time_iso]
  end

  if attributes.key?(:connect_time)
    self.connect_time = attributes[:connect_time]
  end

  if attributes.key?(:connect_time_iso)
    self.connect_time_iso = attributes[:connect_time_iso]
  end

  if attributes.key?(:end_time)
    self.end_time = attributes[:end_time]
  end

  if attributes.key?(:end_time_iso)
    self.end_time_iso = attributes[:end_time_iso]
  end

  if attributes.key?(:duration)
    self.duration = attributes[:duration]
  end

  if attributes.key?(:connect_duration)
    self.connect_duration = attributes[:connect_duration]
  end

  if attributes.key?(:audio_stream_duration)
    self.audio_stream_duration = attributes[:audio_stream_duration]
  end

  if attributes.key?(:direction)
    self.direction = attributes[:direction]
  end

  if attributes.key?(:answered_by)
    self.answered_by = attributes[:answered_by]
  end

  if attributes.key?(:caller_name)
    self.caller_name = attributes[:caller_name]
  end

  if attributes.key?(:web_rtc)
    self.web_rtc = attributes[:web_rtc]
  end

  if attributes.key?(:subresource_uris)
    self.subresource_uris = attributes[:subresource_uris]
  end

  if attributes.key?(:application_id)
    self.application_id = attributes[:application_id]
  end
end

Instance Attribute Details

#account_idObject

ID of the account that owns this Call.



41
42
43
# File 'lib/freeclimb/models/call_result.rb', line 41

def 
  @account_id
end

#answered_byObject

Returns the value of attribute answered_by.



83
84
85
# File 'lib/freeclimb/models/call_result.rb', line 83

def answered_by
  @answered_by
end

#application_idObject

ApplicationId associated with the Call.



94
95
96
# File 'lib/freeclimb/models/call_result.rb', line 94

def application_id
  @application_id
end

#audio_stream_durationObject

Length of time that the Call used the audio stream in seconds. This value is empty or zero when the Call did not use the audio stream.



79
80
81
# File 'lib/freeclimb/models/call_result.rb', line 79

def audio_stream_duration
  @audio_stream_duration
end

#call_idObject

String that uniquely identifies this Call resource.



35
36
37
# File 'lib/freeclimb/models/call_result.rb', line 35

def call_id
  @call_id
end

#caller_nameObject

The caller ID name (CNAM) for this Call. Empty if unavailable.



86
87
88
# File 'lib/freeclimb/models/call_result.rb', line 86

def caller_name
  @caller_name
end

#connect_durationObject

Length of time that the Call was connected in seconds. Measures time between connectTime and endTime. This value is empty for busy, failed, unanswered or ongoing Calls.



76
77
78
# File 'lib/freeclimb/models/call_result.rb', line 76

def connect_duration
  @connect_duration
end

#connect_timeObject

Time the Call was answered (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT). Empty if the Call has not yet been dialed.



61
62
63
# File 'lib/freeclimb/models/call_result.rb', line 61

def connect_time
  @connect_time
end

#connect_time_isoObject

Time the Call was answered in ISO 8601 format (e.g., 2022-01-01T00:00:00.000Z). Empty if the Call has not yet been dialed.



64
65
66
# File 'lib/freeclimb/models/call_result.rb', line 64

def connect_time_iso
  @connect_time_iso
end

#date_createdObject

The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).



20
21
22
# File 'lib/freeclimb/models/call_result.rb', line 20

def date_created
  @date_created
end

#date_created_isoObject

The date that this resource was created in ISO 8601 format (e.g., 2022-01-01T00:00:00.000Z).



29
30
31
# File 'lib/freeclimb/models/call_result.rb', line 29

def date_created_iso
  @date_created_iso
end

#date_updatedObject

The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).



23
24
25
# File 'lib/freeclimb/models/call_result.rb', line 23

def date_updated
  @date_updated
end

#date_updated_isoObject

The date that this resource was last updated in ISO 8601 format (e.g., 2022-01-01T00:00:00.000Z).



32
33
34
# File 'lib/freeclimb/models/call_result.rb', line 32

def date_updated_iso
  @date_updated_iso
end

#directionObject

Returns the value of attribute direction.



81
82
83
# File 'lib/freeclimb/models/call_result.rb', line 81

def direction
  @direction
end

#durationObject

Total length of the Call in seconds. Measures time between startTime and endTime. This value is empty for busy, failed, unanswered or ongoing Calls.



73
74
75
# File 'lib/freeclimb/models/call_result.rb', line 73

def duration
  @duration
end

#end_timeObject

End time of the Call (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT). Empty if the Call did not complete successfully.



67
68
69
# File 'lib/freeclimb/models/call_result.rb', line 67

def end_time
  @end_time
end

#end_time_isoObject

End time of the Call in ISO 8601 format (e.g., 2022-01-01T00:00:00.000Z). Empty if the Call did not complete successfully.



70
71
72
# File 'lib/freeclimb/models/call_result.rb', line 70

def end_time_iso
  @end_time_iso
end

#fromObject

Phone number that initiated this Call.



44
45
46
# File 'lib/freeclimb/models/call_result.rb', line 44

def from
  @from
end

#parent_call_idObject

ID of the Call that created this leg (child Call).



38
39
40
# File 'lib/freeclimb/models/call_result.rb', line 38

def parent_call_id
  @parent_call_id
end

#phone_number_idObject

If the Call was inbound, this is the ID of the IncomingPhoneNumber that received the Call (DNIS). If the Call was outbound, this is the ID of the phone number from which the Call was placed (ANI).



50
51
52
# File 'lib/freeclimb/models/call_result.rb', line 50

def phone_number_id
  @phone_number_id
end

#revisionObject

Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.



26
27
28
# File 'lib/freeclimb/models/call_result.rb', line 26

def revision
  @revision
end

#start_timeObject

Start time of the Call (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT). Empty if the Call has not yet been dialed.



55
56
57
# File 'lib/freeclimb/models/call_result.rb', line 55

def start_time
  @start_time
end

#start_time_isoObject

Start time of the Call in ISO 8601 format (e.g., 2022-01-01T00:00:00.000Z). Empty if the Call has not yet been dialed.



58
59
60
# File 'lib/freeclimb/models/call_result.rb', line 58

def start_time_iso
  @start_time_iso
end

#statusObject

Returns the value of attribute status.



52
53
54
# File 'lib/freeclimb/models/call_result.rb', line 52

def status
  @status
end

#subresource_urisObject

Returns the value of attribute subresource_uris.



91
92
93
# File 'lib/freeclimb/models/call_result.rb', line 91

def subresource_uris
  @subresource_uris
end

#toObject

Phone number that received this Call.



47
48
49
# File 'lib/freeclimb/models/call_result.rb', line 47

def to
  @to
end

#uriObject

The URI for this resource, relative to /apiserver.



17
18
19
# File 'lib/freeclimb/models/call_result.rb', line 17

def uri
  @uri
end

#web_rtcObject

Indicates whether this Call was initiated via WebRTC.



89
90
91
# File 'lib/freeclimb/models/call_result.rb', line 89

def web_rtc
  @web_rtc
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



153
154
155
# File 'lib/freeclimb/models/call_result.rb', line 153

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/freeclimb/models/call_result.rb', line 119

def self.attribute_map
  {
    uri: :uri,
    date_created: :dateCreated,
    date_updated: :dateUpdated,
    revision: :revision,
    date_created_iso: :dateCreatedISO,
    date_updated_iso: :dateUpdatedISO,
    call_id: :callId,
    parent_call_id: :parentCallId,
    account_id: :accountId,
    from: :from,
    to: :to,
    phone_number_id: :phoneNumberId,
    status: :status,
    start_time: :startTime,
    start_time_iso: :startTimeISO,
    connect_time: :connectTime,
    connect_time_iso: :connectTimeISO,
    end_time: :endTime,
    end_time_iso: :endTimeISO,
    duration: :duration,
    connect_duration: :connectDuration,
    audio_stream_duration: :audioStreamDuration,
    direction: :direction,
    answered_by: :answeredBy,
    caller_name: :callerName,
    web_rtc: :webRTC,
    subresource_uris: :subresourceUris,
    application_id: :applicationId
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



422
423
424
# File 'lib/freeclimb/models/call_result.rb', line 422

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



222
223
224
225
226
# File 'lib/freeclimb/models/call_result.rb', line 222

def self.openapi_all_of
  [
    :MutableResourceModel
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/freeclimb/models/call_result.rb', line 192

def self.openapi_nullable
  Set.new([
    :date_created_iso,
    :date_updated_iso,
    :call_id,
    :parent_call_id,
    :account_id,
    :from,
    :to,
    :phone_number_id,
    :status,
    :start_time,
    :start_time_iso,
    :connect_time,
    :connect_time_iso,
    :end_time,
    :end_time_iso,
    :duration,
    :connect_duration,
    :audio_stream_duration,
    :direction,
    :answered_by,
    :caller_name,
    :web_rtc,
    :subresource_uris,
    :application_id
  ])
end

.openapi_typesObject

Attribute type mapping.



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/freeclimb/models/call_result.rb', line 158

def self.openapi_types
  {
    uri: :String,
    date_created: :String,
    date_updated: :String,
    revision: :Integer,
    date_created_iso: :Time,
    date_updated_iso: :Time,
    call_id: :String,
    parent_call_id: :String,
    account_id: :String,
    from: :String,
    to: :String,
    phone_number_id: :String,
    status: :CallStatus,
    start_time: :String,
    start_time_iso: :Time,
    connect_time: :String,
    connect_time_iso: :Time,
    end_time: :String,
    end_time_iso: :Time,
    duration: :Integer,
    connect_duration: :Integer,
    audio_stream_duration: :Integer,
    direction: :CallDirection,
    answered_by: :AnsweredBy,
    caller_name: :String,
    web_rtc: :Boolean,
    subresource_uris: :CallResultAllOfSubresourceUris,
    application_id: :String
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/freeclimb/models/call_result.rb', line 374

def ==(other)
  return true if equal?(other)
  self.class == other.class &&
    uri == other.uri &&
    date_created == other.date_created &&
    date_updated == other.date_updated &&
    revision == other.revision &&
    date_created_iso == other.date_created_iso &&
    date_updated_iso == other.date_updated_iso &&
    call_id == other.call_id &&
    parent_call_id == other.parent_call_id &&
     == other. &&
    from == other.from &&
    to == other.to &&
    phone_number_id == other.phone_number_id &&
    status == other.status &&
    start_time == other.start_time &&
    start_time_iso == other.start_time_iso &&
    connect_time == other.connect_time &&
    connect_time_iso == other.connect_time_iso &&
    end_time == other.end_time &&
    end_time_iso == other.end_time_iso &&
    duration == other.duration &&
    connect_duration == other.connect_duration &&
    audio_stream_duration == other.audio_stream_duration &&
    direction == other.direction &&
    answered_by == other.answered_by &&
    caller_name == other.caller_name &&
    web_rtc == other.web_rtc &&
    subresource_uris == other.subresource_uris &&
    application_id == other.application_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/freeclimb/models/call_result.rb', line 452

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Freeclimb.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



523
524
525
526
527
528
529
530
531
532
533
534
535
# File 'lib/freeclimb/models/call_result.rb', line 523

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/freeclimb/models/call_result.rb', line 429

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      send(:"#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        send(:"#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      send(:"#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


409
410
411
# File 'lib/freeclimb/models/call_result.rb', line 409

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



415
416
417
# File 'lib/freeclimb/models/call_result.rb', line 415

def hash
  [uri, date_created, date_updated, revision, date_created_iso, date_updated_iso, call_id, parent_call_id, , from, to, phone_number_id, status, start_time, start_time_iso, connect_time, connect_time_iso, end_time, end_time_iso, duration, connect_duration, audio_stream_duration, direction, answered_by, caller_name, web_rtc, subresource_uris, application_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



358
359
360
# File 'lib/freeclimb/models/call_result.rb', line 358

def list_invalid_properties
  []
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



499
500
501
# File 'lib/freeclimb/models/call_result.rb', line 499

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'lib/freeclimb/models/call_result.rb', line 505

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



493
494
495
# File 'lib/freeclimb/models/call_result.rb', line 493

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



364
365
366
367
368
369
370
# File 'lib/freeclimb/models/call_result.rb', line 364

def valid?
  if @uri.nil?
    false
  else
    list_invalid_properties.length == 0
  end
end